@@ -5,18 +5,20 @@
 #' @param routes A routes (list).
 #' @param path A path.
 #' @return Boolean value indicating if path is defined.
+#' @keywords internal
 valid_path <- function(routes, path) {
   (path %in% names(routes))
 }
 
-#' Formats a URL fragment into a hashpath starting with "#!/"
+#' Formats a URL fragment into a hash path starting with "#!/"
 #'
 #' @param hashpath character with hash path
-#' @return character with formatted hashpath
+#' @return character with formatted hash path
+#' @keywords internal
 cleanup_hashpath <- function(hashpath) {
-  hashpath = hashpath[1]
+  hashpath <- hashpath[1]
   # Already correctly formatted.
-  if (substr(hashpath, 1, 3) == "#!/" | substr(hashpath, 1, 1) == "?") {
+  if (substr(hashpath, 1, 3) == "#!/" || substr(hashpath, 1, 1) == "?") {
     return(hashpath)
   }
 
@@ -38,6 +40,7 @@ cleanup_hashpath <- function(hashpath) {
 #'
 #' @param path character with link path
 #' @return stripped link
+#' @keywords internal
 extract_link_name <- function(path) {
   sub("#!/", "", cleanup_hashpath(path))
 }
@@ -68,7 +71,7 @@ route_link <- function(path) {
 #'  \item query, a list
 #' }
 #' @details
-#' \code{parse_url_path} allows parsing paramaters lists from url. See more in examples.
+#' \code{parse_url_path} allows parsing parameters lists from url. See more in examples.
 #'
 #' Note that having query string appear before \code{#!} may cause browser to refresh
 #' and thus reset Shiny session.
@@ -91,16 +94,16 @@ parse_url_path <- function(url_path) {
   path <- ""
   query <- NULL
 
-  if (url_has_query & url_has_hash) {
+  if (url_has_query && url_has_hash) {
     # Query string may appear before or after hash
-    if(url_query_pos < url_hash_pos) {
+    if (url_query_pos < url_hash_pos) {
       query <- extracted_url_parts[2]
       path <- extracted_url_parts[3]
     } else {
       query <- extracted_url_parts[3]
       path <- extracted_url_parts[2]
     }
-  } else if (!url_has_query & url_has_hash) {
+  } else if (!url_has_query && url_has_hash) {
     path <- extracted_url_parts[2]
   } else {
     query <- extracted_url_parts[2]
